#!/bin/sh

if ! command -v java >/dev/null 2>&1; then
    echo "Java Runtime Environment is not installed!"
    echo "JRE 17 or newer version is required"
    exit 1
fi

version=$(java -version 2>&1 | awk -F'"' '/version/ {print $2}')
echo "Detected Java version: $version"

major_version=$(echo "$version" | awk -F'[._]' '{
    if ($1 == 1 && $2 == 8)
        print 8
    else if ($1 == 1)
        print $2
    else
        print $1
}')

if [ -z "$major_version" ] || [ "$major_version" -lt 17 ]; then
    echo
    echo "[WARNING] Current Java Runtime version $major_version is older than JRE 17"
    echo "Please upgrade to JRE 17 or newer"
    echo
    exit 1
else
    echo "Java version meets requirement JRE $major_version"
    echo "Starting Omada discovery tool..."
    exec java -jar omada-discovery-utility-5.2.4.jar -Xmx512m
fi
